/****************************************************************************
** Meta object code from reading C++ file 'OAIMeDriveApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIMeDriveApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIMeDriveApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIMeDriveApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIMeDriveApi",
        "getHomeSignal",
        "",
        "OAIDrive",
        "summary",
        "getHomeSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "getHomeSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "getHomeSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'getHomeSignal'
        QtMocHelpers::SignalData<void(OAIDrive)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'getHomeSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIDrive)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'getHomeSignalE'
        QtMocHelpers::SignalData<void(OAIDrive, QNetworkReply::NetworkError, QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'getHomeSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIMeDriveApi, qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIMeDriveApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIMeDriveApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIMeDriveApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->getHomeSignal((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1]))); break;
        case 1: _t->getHomeSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[2]))); break;
        case 2: _t->getHomeSignalE((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->getHomeSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->abortRequestsSignal(); break;
        case 5: _t->allPendingRequestsCompleted(); break;
        case 6: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIMeDriveApi::*)(OAIDrive )>(_a, &OAIMeDriveApi::getHomeSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIMeDriveApi::*)(OAIHttpRequestWorker * , OAIDrive )>(_a, &OAIMeDriveApi::getHomeSignalFull, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIMeDriveApi::*)(OAIDrive , QNetworkReply::NetworkError , QString )>(_a, &OAIMeDriveApi::getHomeSignalE, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIMeDriveApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIMeDriveApi::getHomeSignalEFull, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIMeDriveApi::*)()>(_a, &OAIMeDriveApi::abortRequestsSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIMeDriveApi::*)()>(_a, &OAIMeDriveApi::allPendingRequestsCompleted, 5))
            return;
    }
}

const QMetaObject *OpenAPI::OAIMeDriveApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIMeDriveApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI13OAIMeDriveApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIMeDriveApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIMeDriveApi::getHomeSignal(OAIDrive _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OpenAPI::OAIMeDriveApi::getHomeSignalFull(OAIHttpRequestWorker * _t1, OAIDrive _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OpenAPI::OAIMeDriveApi::getHomeSignalE(OAIDrive _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void OpenAPI::OAIMeDriveApi::getHomeSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void OpenAPI::OAIMeDriveApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OpenAPI::OAIMeDriveApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
