/****************************************************************************
** Meta object code from reading C++ file 'OAIDrivesRootApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIDrivesRootApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIDrivesRootApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIDrivesRootApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIDrivesRootApi",
        "getRootSignal",
        "",
        "OAIDriveItem",
        "summary",
        "getRootSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "getRootSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "getRootSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'getRootSignal'
        QtMocHelpers::SignalData<void(OAIDriveItem)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'getRootSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIDriveItem)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'getRootSignalE'
        QtMocHelpers::SignalData<void(OAIDriveItem, QNetworkReply::NetworkError, QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'getRootSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIDrivesRootApi, qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIDrivesRootApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIDrivesRootApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIDrivesRootApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->getRootSignal((*reinterpret_cast<std::add_pointer_t<OAIDriveItem>>(_a[1]))); break;
        case 1: _t->getRootSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIDriveItem>>(_a[2]))); break;
        case 2: _t->getRootSignalE((*reinterpret_cast<std::add_pointer_t<OAIDriveItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->getRootSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->abortRequestsSignal(); break;
        case 5: _t->allPendingRequestsCompleted(); break;
        case 6: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesRootApi::*)(OAIDriveItem )>(_a, &OAIDrivesRootApi::getRootSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesRootApi::*)(OAIHttpRequestWorker * , OAIDriveItem )>(_a, &OAIDrivesRootApi::getRootSignalFull, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesRootApi::*)(OAIDriveItem , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesRootApi::getRootSignalE, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesRootApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesRootApi::getRootSignalEFull, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesRootApi::*)()>(_a, &OAIDrivesRootApi::abortRequestsSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesRootApi::*)()>(_a, &OAIDrivesRootApi::allPendingRequestsCompleted, 5))
            return;
    }
}

const QMetaObject *OpenAPI::OAIDrivesRootApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIDrivesRootApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI16OAIDrivesRootApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIDrivesRootApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIDrivesRootApi::getRootSignal(OAIDriveItem _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OpenAPI::OAIDrivesRootApi::getRootSignalFull(OAIHttpRequestWorker * _t1, OAIDriveItem _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OpenAPI::OAIDrivesRootApi::getRootSignalE(OAIDriveItem _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void OpenAPI::OAIDrivesRootApi::getRootSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void OpenAPI::OAIDrivesRootApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OpenAPI::OAIDrivesRootApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
