/****************************************************************************
** Meta object code from reading C++ file 'OAIEducationSchoolApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIEducationSchoolApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIEducationSchoolApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIEducationSchoolApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIEducationSchoolApi",
        "addClassToSchoolSignal",
        "",
        "addUserToSchoolSignal",
        "createSchoolSignal",
        "OAIEducationSchool",
        "summary",
        "deleteClassFromSchoolSignal",
        "deleteSchoolSignal",
        "deleteUserFromSchoolSignal",
        "getSchoolSignal",
        "listSchoolClassesSignal",
        "OAICollection_of_educationClass",
        "listSchoolUsersSignal",
        "OAICollection_of_educationUser_1",
        "listSchoolsSignal",
        "OAICollection_of_schools",
        "updateSchoolSignal",
        "addClassToSchoolSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "addUserToSchoolSignalFull",
        "createSchoolSignalFull",
        "deleteClassFromSchoolSignalFull",
        "deleteSchoolSignalFull",
        "deleteUserFromSchoolSignalFull",
        "getSchoolSignalFull",
        "listSchoolClassesSignalFull",
        "listSchoolUsersSignalFull",
        "listSchoolsSignalFull",
        "updateSchoolSignalFull",
        "addClassToSchoolSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "addUserToSchoolSignalE",
        "createSchoolSignalE",
        "deleteClassFromSchoolSignalE",
        "deleteSchoolSignalE",
        "deleteUserFromSchoolSignalE",
        "getSchoolSignalE",
        "listSchoolClassesSignalE",
        "listSchoolUsersSignalE",
        "listSchoolsSignalE",
        "updateSchoolSignalE",
        "addClassToSchoolSignalEFull",
        "addUserToSchoolSignalEFull",
        "createSchoolSignalEFull",
        "deleteClassFromSchoolSignalEFull",
        "deleteSchoolSignalEFull",
        "deleteUserFromSchoolSignalEFull",
        "getSchoolSignalEFull",
        "listSchoolClassesSignalEFull",
        "listSchoolUsersSignalEFull",
        "listSchoolsSignalEFull",
        "updateSchoolSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addClassToSchoolSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addUserToSchoolSignal'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createSchoolSignal'
        QtMocHelpers::SignalData<void(OAIEducationSchool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'deleteClassFromSchoolSignal'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteSchoolSignal'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteUserFromSchoolSignal'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'getSchoolSignal'
        QtMocHelpers::SignalData<void(OAIEducationSchool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'listSchoolClassesSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_educationClass)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 6 },
        }}),
        // Signal 'listSchoolUsersSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_educationUser_1)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 6 },
        }}),
        // Signal 'listSchoolsSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_schools)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 6 },
        }}),
        // Signal 'updateSchoolSignal'
        QtMocHelpers::SignalData<void(OAIEducationSchool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'addClassToSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'addUserToSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'createSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationSchool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'deleteClassFromSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'deleteSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'deleteUserFromSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'getSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationSchool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'listSchoolClassesSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_educationClass)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 12, 6 },
        }}),
        // Signal 'listSchoolUsersSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_educationUser_1)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 14, 6 },
        }}),
        // Signal 'listSchoolsSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_schools)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 16, 6 },
        }}),
        // Signal 'updateSchoolSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationSchool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'addClassToSchoolSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'addUserToSchoolSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'createSchoolSignalE'
        QtMocHelpers::SignalData<void(OAIEducationSchool, QNetworkReply::NetworkError, QString)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'deleteClassFromSchoolSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'deleteSchoolSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'deleteUserFromSchoolSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'getSchoolSignalE'
        QtMocHelpers::SignalData<void(OAIEducationSchool, QNetworkReply::NetworkError, QString)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'listSchoolClassesSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_educationClass, QNetworkReply::NetworkError, QString)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 6 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'listSchoolUsersSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_educationUser_1, QNetworkReply::NetworkError, QString)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 6 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'listSchoolsSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_schools, QNetworkReply::NetworkError, QString)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 6 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'updateSchoolSignalE'
        QtMocHelpers::SignalData<void(OAIEducationSchool, QNetworkReply::NetworkError, QString)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'addClassToSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'addUserToSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'createSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'deleteClassFromSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'deleteSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'deleteUserFromSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'getSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'listSchoolClassesSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'listSchoolUsersSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'listSchoolsSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'updateSchoolSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIEducationSchoolApi, qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIEducationSchoolApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIEducationSchoolApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIEducationSchoolApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addClassToSchoolSignal(); break;
        case 1: _t->addUserToSchoolSignal(); break;
        case 2: _t->createSchoolSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[1]))); break;
        case 3: _t->deleteClassFromSchoolSignal(); break;
        case 4: _t->deleteSchoolSignal(); break;
        case 5: _t->deleteUserFromSchoolSignal(); break;
        case 6: _t->getSchoolSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[1]))); break;
        case 7: _t->listSchoolClassesSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationClass>>(_a[1]))); break;
        case 8: _t->listSchoolUsersSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser_1>>(_a[1]))); break;
        case 9: _t->listSchoolsSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_schools>>(_a[1]))); break;
        case 10: _t->updateSchoolSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[1]))); break;
        case 11: _t->addClassToSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 12: _t->addUserToSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 13: _t->createSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[2]))); break;
        case 14: _t->deleteClassFromSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 15: _t->deleteSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 16: _t->deleteUserFromSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 17: _t->getSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[2]))); break;
        case 18: _t->listSchoolClassesSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationClass>>(_a[2]))); break;
        case 19: _t->listSchoolUsersSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser_1>>(_a[2]))); break;
        case 20: _t->listSchoolsSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_schools>>(_a[2]))); break;
        case 21: _t->updateSchoolSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[2]))); break;
        case 22: _t->addClassToSchoolSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->addUserToSchoolSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->createSchoolSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 25: _t->deleteClassFromSchoolSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->deleteSchoolSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: _t->deleteUserFromSchoolSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 28: _t->getSchoolSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 29: _t->listSchoolClassesSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationClass>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 30: _t->listSchoolUsersSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser_1>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 31: _t->listSchoolsSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_schools>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 32: _t->updateSchoolSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationSchool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 33: _t->addClassToSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 34: _t->addUserToSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 35: _t->createSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 36: _t->deleteClassFromSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 37: _t->deleteSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 38: _t->deleteUserFromSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 39: _t->getSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 40: _t->listSchoolClassesSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 41: _t->listSchoolUsersSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 42: _t->listSchoolsSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 43: _t->updateSchoolSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 44: _t->abortRequestsSignal(); break;
        case 45: _t->allPendingRequestsCompleted(); break;
        case 46: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::addClassToSchoolSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::addUserToSchoolSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIEducationSchool )>(_a, &OAIEducationSchoolApi::createSchoolSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::deleteClassFromSchoolSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::deleteSchoolSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::deleteUserFromSchoolSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIEducationSchool )>(_a, &OAIEducationSchoolApi::getSchoolSignal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAICollection_of_educationClass )>(_a, &OAIEducationSchoolApi::listSchoolClassesSignal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAICollection_of_educationUser_1 )>(_a, &OAIEducationSchoolApi::listSchoolUsersSignal, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAICollection_of_schools )>(_a, &OAIEducationSchoolApi::listSchoolsSignal, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIEducationSchool )>(_a, &OAIEducationSchoolApi::updateSchoolSignal, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationSchoolApi::addClassToSchoolSignalFull, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationSchoolApi::addUserToSchoolSignalFull, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , OAIEducationSchool )>(_a, &OAIEducationSchoolApi::createSchoolSignalFull, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationSchoolApi::deleteClassFromSchoolSignalFull, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationSchoolApi::deleteSchoolSignalFull, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationSchoolApi::deleteUserFromSchoolSignalFull, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , OAIEducationSchool )>(_a, &OAIEducationSchoolApi::getSchoolSignalFull, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , OAICollection_of_educationClass )>(_a, &OAIEducationSchoolApi::listSchoolClassesSignalFull, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , OAICollection_of_educationUser_1 )>(_a, &OAIEducationSchoolApi::listSchoolUsersSignalFull, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , OAICollection_of_schools )>(_a, &OAIEducationSchoolApi::listSchoolsSignalFull, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , OAIEducationSchool )>(_a, &OAIEducationSchoolApi::updateSchoolSignalFull, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::addClassToSchoolSignalE, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::addUserToSchoolSignalE, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIEducationSchool , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::createSchoolSignalE, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::deleteClassFromSchoolSignalE, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::deleteSchoolSignalE, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::deleteUserFromSchoolSignalE, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIEducationSchool , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::getSchoolSignalE, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAICollection_of_educationClass , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::listSchoolClassesSignalE, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAICollection_of_educationUser_1 , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::listSchoolUsersSignalE, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAICollection_of_schools , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::listSchoolsSignalE, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIEducationSchool , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::updateSchoolSignalE, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::addClassToSchoolSignalEFull, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::addUserToSchoolSignalEFull, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::createSchoolSignalEFull, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::deleteClassFromSchoolSignalEFull, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::deleteSchoolSignalEFull, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::deleteUserFromSchoolSignalEFull, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::getSchoolSignalEFull, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::listSchoolClassesSignalEFull, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::listSchoolUsersSignalEFull, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::listSchoolsSignalEFull, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationSchoolApi::updateSchoolSignalEFull, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::abortRequestsSignal, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationSchoolApi::*)()>(_a, &OAIEducationSchoolApi::allPendingRequestsCompleted, 45))
            return;
    }
}

const QMetaObject *OpenAPI::OAIEducationSchoolApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIEducationSchoolApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI21OAIEducationSchoolApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIEducationSchoolApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIEducationSchoolApi::addClassToSchoolSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OpenAPI::OAIEducationSchoolApi::addUserToSchoolSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OpenAPI::OAIEducationSchoolApi::createSchoolSignal(OAIEducationSchool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OpenAPI::OAIEducationSchoolApi::deleteClassFromSchoolSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OpenAPI::OAIEducationSchoolApi::deleteSchoolSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OpenAPI::OAIEducationSchoolApi::deleteUserFromSchoolSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OpenAPI::OAIEducationSchoolApi::getSchoolSignal(OAIEducationSchool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OpenAPI::OAIEducationSchoolApi::listSchoolClassesSignal(OAICollection_of_educationClass _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OpenAPI::OAIEducationSchoolApi::listSchoolUsersSignal(OAICollection_of_educationUser_1 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void OpenAPI::OAIEducationSchoolApi::listSchoolsSignal(OAICollection_of_schools _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void OpenAPI::OAIEducationSchoolApi::updateSchoolSignal(OAIEducationSchool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void OpenAPI::OAIEducationSchoolApi::addClassToSchoolSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void OpenAPI::OAIEducationSchoolApi::addUserToSchoolSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void OpenAPI::OAIEducationSchoolApi::createSchoolSignalFull(OAIHttpRequestWorker * _t1, OAIEducationSchool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void OpenAPI::OAIEducationSchoolApi::deleteClassFromSchoolSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void OpenAPI::OAIEducationSchoolApi::deleteSchoolSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void OpenAPI::OAIEducationSchoolApi::deleteUserFromSchoolSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void OpenAPI::OAIEducationSchoolApi::getSchoolSignalFull(OAIHttpRequestWorker * _t1, OAIEducationSchool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void OpenAPI::OAIEducationSchoolApi::listSchoolClassesSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_educationClass _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void OpenAPI::OAIEducationSchoolApi::listSchoolUsersSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_educationUser_1 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void OpenAPI::OAIEducationSchoolApi::listSchoolsSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_schools _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2);
}

// SIGNAL 21
void OpenAPI::OAIEducationSchoolApi::updateSchoolSignalFull(OAIHttpRequestWorker * _t1, OAIEducationSchool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void OpenAPI::OAIEducationSchoolApi::addClassToSchoolSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2);
}

// SIGNAL 23
void OpenAPI::OAIEducationSchoolApi::addUserToSchoolSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}

// SIGNAL 24
void OpenAPI::OAIEducationSchoolApi::createSchoolSignalE(OAIEducationSchool _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2, _t3);
}

// SIGNAL 25
void OpenAPI::OAIEducationSchoolApi::deleteClassFromSchoolSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2);
}

// SIGNAL 26
void OpenAPI::OAIEducationSchoolApi::deleteSchoolSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void OpenAPI::OAIEducationSchoolApi::deleteUserFromSchoolSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2);
}

// SIGNAL 28
void OpenAPI::OAIEducationSchoolApi::getSchoolSignalE(OAIEducationSchool _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2, _t3);
}

// SIGNAL 29
void OpenAPI::OAIEducationSchoolApi::listSchoolClassesSignalE(OAICollection_of_educationClass _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2, _t3);
}

// SIGNAL 30
void OpenAPI::OAIEducationSchoolApi::listSchoolUsersSignalE(OAICollection_of_educationUser_1 _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2, _t3);
}

// SIGNAL 31
void OpenAPI::OAIEducationSchoolApi::listSchoolsSignalE(OAICollection_of_schools _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1, _t2, _t3);
}

// SIGNAL 32
void OpenAPI::OAIEducationSchoolApi::updateSchoolSignalE(OAIEducationSchool _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1, _t2, _t3);
}

// SIGNAL 33
void OpenAPI::OAIEducationSchoolApi::addClassToSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1, _t2, _t3);
}

// SIGNAL 34
void OpenAPI::OAIEducationSchoolApi::addUserToSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1, _t2, _t3);
}

// SIGNAL 35
void OpenAPI::OAIEducationSchoolApi::createSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1, _t2, _t3);
}

// SIGNAL 36
void OpenAPI::OAIEducationSchoolApi::deleteClassFromSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1, _t2, _t3);
}

// SIGNAL 37
void OpenAPI::OAIEducationSchoolApi::deleteSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1, _t2, _t3);
}

// SIGNAL 38
void OpenAPI::OAIEducationSchoolApi::deleteUserFromSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1, _t2, _t3);
}

// SIGNAL 39
void OpenAPI::OAIEducationSchoolApi::getSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1, _t2, _t3);
}

// SIGNAL 40
void OpenAPI::OAIEducationSchoolApi::listSchoolClassesSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1, _t2, _t3);
}

// SIGNAL 41
void OpenAPI::OAIEducationSchoolApi::listSchoolUsersSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1, _t2, _t3);
}

// SIGNAL 42
void OpenAPI::OAIEducationSchoolApi::listSchoolsSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1, _t2, _t3);
}

// SIGNAL 43
void OpenAPI::OAIEducationSchoolApi::updateSchoolSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1, _t2, _t3);
}

// SIGNAL 44
void OpenAPI::OAIEducationSchoolApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void OpenAPI::OAIEducationSchoolApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}
QT_WARNING_POP
