// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_OAIApplicationsApi.cpp"
#include "EWIEGA46WW/moc_OAIDrivesApi.cpp"
#include "EWIEGA46WW/moc_OAIDrivesGetDrivesApi.cpp"
#include "EWIEGA46WW/moc_OAIDrivesRootApi.cpp"
#include "EWIEGA46WW/moc_OAIEducationClassApi.cpp"
#include "EWIEGA46WW/moc_OAIEducationClassTeachersApi.cpp"
#include "EWIEGA46WW/moc_OAIEducationSchoolApi.cpp"
#include "EWIEGA46WW/moc_OAIEducationUserApi.cpp"
#include "EWIEGA46WW/moc_OAIGroupApi.cpp"
#include "EWIEGA46WW/moc_OAIGroupsApi.cpp"
#include "EWIEGA46WW/moc_OAIHttpRequest.cpp"
#include "EWIEGA46WW/moc_OAIMeChangepasswordApi.cpp"
#include "EWIEGA46WW/moc_OAIMeDriveApi.cpp"
#include "EWIEGA46WW/moc_OAIMeDriveRootApi.cpp"
#include "EWIEGA46WW/moc_OAIMeDriveRootChildrenApi.cpp"
#include "EWIEGA46WW/moc_OAIMeDrivesApi.cpp"
#include "EWIEGA46WW/moc_OAIMeUserApi.cpp"
#include "EWIEGA46WW/moc_OAIOauth.cpp"
#include "EWIEGA46WW/moc_OAITagsApi.cpp"
#include "EWIEGA46WW/moc_OAIUserApi.cpp"
#include "EWIEGA46WW/moc_OAIUserAppRoleAssignmentApi.cpp"
#include "EWIEGA46WW/moc_OAIUsersApi.cpp"
