/****************************************************************************
** Meta object code from reading C++ file 'OAIUserAppRoleAssignmentApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIUserAppRoleAssignmentApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIUserAppRoleAssignmentApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIUserAppRoleAssignmentApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIUserAppRoleAssignmentApi",
        "user_CreateAppRoleAssignmentsSignal",
        "",
        "OAIAppRoleAssignment",
        "summary",
        "user_DeleteAppRoleAssignmentsSignal",
        "user_ListAppRoleAssignmentsSignal",
        "OAICollection_of_appRoleAssignments",
        "user_CreateAppRoleAssignmentsSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "user_DeleteAppRoleAssignmentsSignalFull",
        "user_ListAppRoleAssignmentsSignalFull",
        "user_CreateAppRoleAssignmentsSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "user_DeleteAppRoleAssignmentsSignalE",
        "user_ListAppRoleAssignmentsSignalE",
        "user_CreateAppRoleAssignmentsSignalEFull",
        "user_DeleteAppRoleAssignmentsSignalEFull",
        "user_ListAppRoleAssignmentsSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'user_CreateAppRoleAssignmentsSignal'
        QtMocHelpers::SignalData<void(OAIAppRoleAssignment)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'user_DeleteAppRoleAssignmentsSignal'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'user_ListAppRoleAssignmentsSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_appRoleAssignments)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 },
        }}),
        // Signal 'user_CreateAppRoleAssignmentsSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIAppRoleAssignment)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'user_DeleteAppRoleAssignmentsSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'user_ListAppRoleAssignmentsSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_appRoleAssignments)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 7, 4 },
        }}),
        // Signal 'user_CreateAppRoleAssignmentsSignalE'
        QtMocHelpers::SignalData<void(OAIAppRoleAssignment, QNetworkReply::NetworkError, QString)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'user_DeleteAppRoleAssignmentsSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'user_ListAppRoleAssignmentsSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_appRoleAssignments, QNetworkReply::NetworkError, QString)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 }, { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'user_CreateAppRoleAssignmentsSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'user_DeleteAppRoleAssignmentsSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'user_ListAppRoleAssignmentsSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIUserAppRoleAssignmentApi, qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIUserAppRoleAssignmentApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIUserAppRoleAssignmentApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIUserAppRoleAssignmentApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->user_CreateAppRoleAssignmentsSignal((*reinterpret_cast<std::add_pointer_t<OAIAppRoleAssignment>>(_a[1]))); break;
        case 1: _t->user_DeleteAppRoleAssignmentsSignal(); break;
        case 2: _t->user_ListAppRoleAssignmentsSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_appRoleAssignments>>(_a[1]))); break;
        case 3: _t->user_CreateAppRoleAssignmentsSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIAppRoleAssignment>>(_a[2]))); break;
        case 4: _t->user_DeleteAppRoleAssignmentsSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 5: _t->user_ListAppRoleAssignmentsSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_appRoleAssignments>>(_a[2]))); break;
        case 6: _t->user_CreateAppRoleAssignmentsSignalE((*reinterpret_cast<std::add_pointer_t<OAIAppRoleAssignment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->user_DeleteAppRoleAssignmentsSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->user_ListAppRoleAssignmentsSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_appRoleAssignments>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->user_CreateAppRoleAssignmentsSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->user_DeleteAppRoleAssignmentsSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: _t->user_ListAppRoleAssignmentsSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->abortRequestsSignal(); break;
        case 13: _t->allPendingRequestsCompleted(); break;
        case 14: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIAppRoleAssignment )>(_a, &OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)()>(_a, &OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAICollection_of_appRoleAssignments )>(_a, &OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIHttpRequestWorker * , OAIAppRoleAssignment )>(_a, &OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignalFull, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIHttpRequestWorker * )>(_a, &OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignalFull, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIHttpRequestWorker * , OAICollection_of_appRoleAssignments )>(_a, &OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignalFull, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIAppRoleAssignment , QNetworkReply::NetworkError , QString )>(_a, &OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignalE, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignalE, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAICollection_of_appRoleAssignments , QNetworkReply::NetworkError , QString )>(_a, &OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignalE, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignalEFull, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignalEFull, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignalEFull, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)()>(_a, &OAIUserAppRoleAssignmentApi::abortRequestsSignal, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIUserAppRoleAssignmentApi::*)()>(_a, &OAIUserAppRoleAssignmentApi::allPendingRequestsCompleted, 13))
            return;
    }
}

const QMetaObject *OpenAPI::OAIUserAppRoleAssignmentApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIUserAppRoleAssignmentApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI27OAIUserAppRoleAssignmentApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIUserAppRoleAssignmentApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignal(OAIAppRoleAssignment _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OpenAPI::OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OpenAPI::OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignal(OAICollection_of_appRoleAssignments _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OpenAPI::OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignalFull(OAIHttpRequestWorker * _t1, OAIAppRoleAssignment _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void OpenAPI::OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OpenAPI::OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_appRoleAssignments _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OpenAPI::OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignalE(OAIAppRoleAssignment _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void OpenAPI::OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void OpenAPI::OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignalE(OAICollection_of_appRoleAssignments _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void OpenAPI::OAIUserAppRoleAssignmentApi::user_CreateAppRoleAssignmentsSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void OpenAPI::OAIUserAppRoleAssignmentApi::user_DeleteAppRoleAssignmentsSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void OpenAPI::OAIUserAppRoleAssignmentApi::user_ListAppRoleAssignmentsSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void OpenAPI::OAIUserAppRoleAssignmentApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void OpenAPI::OAIUserAppRoleAssignmentApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
