/****************************************************************************
** Meta object code from reading C++ file 'OAIDrivesApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIDrivesApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIDrivesApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIDrivesApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIDrivesApi",
        "createDriveSignal",
        "",
        "OAIDrive",
        "summary",
        "deleteDriveSignal",
        "getDriveSignal",
        "updateDriveSignal",
        "createDriveSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "deleteDriveSignalFull",
        "getDriveSignalFull",
        "updateDriveSignalFull",
        "createDriveSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "deleteDriveSignalE",
        "getDriveSignalE",
        "updateDriveSignalE",
        "createDriveSignalEFull",
        "deleteDriveSignalEFull",
        "getDriveSignalEFull",
        "updateDriveSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'createDriveSignal'
        QtMocHelpers::SignalData<void(OAIDrive)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deleteDriveSignal'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'getDriveSignal'
        QtMocHelpers::SignalData<void(OAIDrive)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updateDriveSignal'
        QtMocHelpers::SignalData<void(OAIDrive)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'createDriveSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIDrive)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deleteDriveSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'getDriveSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIDrive)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updateDriveSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIDrive)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'createDriveSignalE'
        QtMocHelpers::SignalData<void(OAIDrive, QNetworkReply::NetworkError, QString)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'deleteDriveSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'getDriveSignalE'
        QtMocHelpers::SignalData<void(OAIDrive, QNetworkReply::NetworkError, QString)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'updateDriveSignalE'
        QtMocHelpers::SignalData<void(OAIDrive, QNetworkReply::NetworkError, QString)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'createDriveSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'deleteDriveSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'getDriveSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'updateDriveSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIDrivesApi, qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIDrivesApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIDrivesApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIDrivesApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createDriveSignal((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1]))); break;
        case 1: _t->deleteDriveSignal(); break;
        case 2: _t->getDriveSignal((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1]))); break;
        case 3: _t->updateDriveSignal((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1]))); break;
        case 4: _t->createDriveSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[2]))); break;
        case 5: _t->deleteDriveSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 6: _t->getDriveSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[2]))); break;
        case 7: _t->updateDriveSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[2]))); break;
        case 8: _t->createDriveSignalE((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->deleteDriveSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->getDriveSignalE((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: _t->updateDriveSignalE((*reinterpret_cast<std::add_pointer_t<OAIDrive>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->createDriveSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 13: _t->deleteDriveSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->getDriveSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->updateDriveSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 16: _t->abortRequestsSignal(); break;
        case 17: _t->allPendingRequestsCompleted(); break;
        case 18: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIDrive )>(_a, &OAIDrivesApi::createDriveSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)()>(_a, &OAIDrivesApi::deleteDriveSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIDrive )>(_a, &OAIDrivesApi::getDriveSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIDrive )>(_a, &OAIDrivesApi::updateDriveSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , OAIDrive )>(_a, &OAIDrivesApi::createDriveSignalFull, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * )>(_a, &OAIDrivesApi::deleteDriveSignalFull, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , OAIDrive )>(_a, &OAIDrivesApi::getDriveSignalFull, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , OAIDrive )>(_a, &OAIDrivesApi::updateDriveSignalFull, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIDrive , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::createDriveSignalE, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::deleteDriveSignalE, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIDrive , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::getDriveSignalE, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIDrive , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::updateDriveSignalE, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::createDriveSignalEFull, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::deleteDriveSignalEFull, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::getDriveSignalEFull, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIDrivesApi::updateDriveSignalEFull, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)()>(_a, &OAIDrivesApi::abortRequestsSignal, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIDrivesApi::*)()>(_a, &OAIDrivesApi::allPendingRequestsCompleted, 17))
            return;
    }
}

const QMetaObject *OpenAPI::OAIDrivesApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIDrivesApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI12OAIDrivesApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIDrivesApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIDrivesApi::createDriveSignal(OAIDrive _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OpenAPI::OAIDrivesApi::deleteDriveSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OpenAPI::OAIDrivesApi::getDriveSignal(OAIDrive _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OpenAPI::OAIDrivesApi::updateDriveSignal(OAIDrive _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OpenAPI::OAIDrivesApi::createDriveSignalFull(OAIHttpRequestWorker * _t1, OAIDrive _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void OpenAPI::OAIDrivesApi::deleteDriveSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OpenAPI::OAIDrivesApi::getDriveSignalFull(OAIHttpRequestWorker * _t1, OAIDrive _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void OpenAPI::OAIDrivesApi::updateDriveSignalFull(OAIHttpRequestWorker * _t1, OAIDrive _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void OpenAPI::OAIDrivesApi::createDriveSignalE(OAIDrive _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void OpenAPI::OAIDrivesApi::deleteDriveSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void OpenAPI::OAIDrivesApi::getDriveSignalE(OAIDrive _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void OpenAPI::OAIDrivesApi::updateDriveSignalE(OAIDrive _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void OpenAPI::OAIDrivesApi::createDriveSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3);
}

// SIGNAL 13
void OpenAPI::OAIDrivesApi::deleteDriveSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void OpenAPI::OAIDrivesApi::getDriveSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void OpenAPI::OAIDrivesApi::updateDriveSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void OpenAPI::OAIDrivesApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void OpenAPI::OAIDrivesApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
