/****************************************************************************
** Meta object code from reading C++ file 'OAIEducationUserApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIEducationUserApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIEducationUserApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIEducationUserApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIEducationUserApi",
        "createEducationUserSignal",
        "",
        "OAIEducationUser",
        "summary",
        "deleteEducationUserSignal",
        "getEducationUserSignal",
        "listEducationUsersSignal",
        "OAICollection_of_educationUser",
        "updateEducationUserSignal",
        "createEducationUserSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "deleteEducationUserSignalFull",
        "getEducationUserSignalFull",
        "listEducationUsersSignalFull",
        "updateEducationUserSignalFull",
        "createEducationUserSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "deleteEducationUserSignalE",
        "getEducationUserSignalE",
        "listEducationUsersSignalE",
        "updateEducationUserSignalE",
        "createEducationUserSignalEFull",
        "deleteEducationUserSignalEFull",
        "getEducationUserSignalEFull",
        "listEducationUsersSignalEFull",
        "updateEducationUserSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'createEducationUserSignal'
        QtMocHelpers::SignalData<void(OAIEducationUser)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deleteEducationUserSignal'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'getEducationUserSignal'
        QtMocHelpers::SignalData<void(OAIEducationUser)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'listEducationUsersSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_educationUser)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Signal 'updateEducationUserSignal'
        QtMocHelpers::SignalData<void(OAIEducationUser)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'createEducationUserSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationUser)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deleteEducationUserSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'getEducationUserSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationUser)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'listEducationUsersSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_educationUser)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 8, 4 },
        }}),
        // Signal 'updateEducationUserSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationUser)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'createEducationUserSignalE'
        QtMocHelpers::SignalData<void(OAIEducationUser, QNetworkReply::NetworkError, QString)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'deleteEducationUserSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'getEducationUserSignalE'
        QtMocHelpers::SignalData<void(OAIEducationUser, QNetworkReply::NetworkError, QString)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'listEducationUsersSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_educationUser, QNetworkReply::NetworkError, QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'updateEducationUserSignalE'
        QtMocHelpers::SignalData<void(OAIEducationUser, QNetworkReply::NetworkError, QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'createEducationUserSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'deleteEducationUserSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'getEducationUserSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'listEducationUsersSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'updateEducationUserSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIEducationUserApi, qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIEducationUserApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIEducationUserApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIEducationUserApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createEducationUserSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[1]))); break;
        case 1: _t->deleteEducationUserSignal(); break;
        case 2: _t->getEducationUserSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[1]))); break;
        case 3: _t->listEducationUsersSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser>>(_a[1]))); break;
        case 4: _t->updateEducationUserSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[1]))); break;
        case 5: _t->createEducationUserSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[2]))); break;
        case 6: _t->deleteEducationUserSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 7: _t->getEducationUserSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[2]))); break;
        case 8: _t->listEducationUsersSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser>>(_a[2]))); break;
        case 9: _t->updateEducationUserSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[2]))); break;
        case 10: _t->createEducationUserSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: _t->deleteEducationUserSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->getEducationUserSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 13: _t->listEducationUsersSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->updateEducationUserSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationUser>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->createEducationUserSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 16: _t->deleteEducationUserSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->getEducationUserSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 18: _t->listEducationUsersSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->updateEducationUserSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 20: _t->abortRequestsSignal(); break;
        case 21: _t->allPendingRequestsCompleted(); break;
        case 22: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIEducationUser )>(_a, &OAIEducationUserApi::createEducationUserSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)()>(_a, &OAIEducationUserApi::deleteEducationUserSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIEducationUser )>(_a, &OAIEducationUserApi::getEducationUserSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAICollection_of_educationUser )>(_a, &OAIEducationUserApi::listEducationUsersSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIEducationUser )>(_a, &OAIEducationUserApi::updateEducationUserSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , OAIEducationUser )>(_a, &OAIEducationUserApi::createEducationUserSignalFull, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationUserApi::deleteEducationUserSignalFull, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , OAIEducationUser )>(_a, &OAIEducationUserApi::getEducationUserSignalFull, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , OAICollection_of_educationUser )>(_a, &OAIEducationUserApi::listEducationUsersSignalFull, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , OAIEducationUser )>(_a, &OAIEducationUserApi::updateEducationUserSignalFull, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIEducationUser , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::createEducationUserSignalE, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::deleteEducationUserSignalE, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIEducationUser , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::getEducationUserSignalE, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAICollection_of_educationUser , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::listEducationUsersSignalE, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIEducationUser , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::updateEducationUserSignalE, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::createEducationUserSignalEFull, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::deleteEducationUserSignalEFull, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::getEducationUserSignalEFull, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::listEducationUsersSignalEFull, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationUserApi::updateEducationUserSignalEFull, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)()>(_a, &OAIEducationUserApi::abortRequestsSignal, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationUserApi::*)()>(_a, &OAIEducationUserApi::allPendingRequestsCompleted, 21))
            return;
    }
}

const QMetaObject *OpenAPI::OAIEducationUserApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIEducationUserApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI19OAIEducationUserApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIEducationUserApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIEducationUserApi::createEducationUserSignal(OAIEducationUser _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OpenAPI::OAIEducationUserApi::deleteEducationUserSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OpenAPI::OAIEducationUserApi::getEducationUserSignal(OAIEducationUser _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OpenAPI::OAIEducationUserApi::listEducationUsersSignal(OAICollection_of_educationUser _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OpenAPI::OAIEducationUserApi::updateEducationUserSignal(OAIEducationUser _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OpenAPI::OAIEducationUserApi::createEducationUserSignalFull(OAIHttpRequestWorker * _t1, OAIEducationUser _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OpenAPI::OAIEducationUserApi::deleteEducationUserSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OpenAPI::OAIEducationUserApi::getEducationUserSignalFull(OAIHttpRequestWorker * _t1, OAIEducationUser _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void OpenAPI::OAIEducationUserApi::listEducationUsersSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_educationUser _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void OpenAPI::OAIEducationUserApi::updateEducationUserSignalFull(OAIHttpRequestWorker * _t1, OAIEducationUser _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void OpenAPI::OAIEducationUserApi::createEducationUserSignalE(OAIEducationUser _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void OpenAPI::OAIEducationUserApi::deleteEducationUserSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void OpenAPI::OAIEducationUserApi::getEducationUserSignalE(OAIEducationUser _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3);
}

// SIGNAL 13
void OpenAPI::OAIEducationUserApi::listEducationUsersSignalE(OAICollection_of_educationUser _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void OpenAPI::OAIEducationUserApi::updateEducationUserSignalE(OAIEducationUser _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void OpenAPI::OAIEducationUserApi::createEducationUserSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void OpenAPI::OAIEducationUserApi::deleteEducationUserSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void OpenAPI::OAIEducationUserApi::getEducationUserSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void OpenAPI::OAIEducationUserApi::listEducationUsersSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3);
}

// SIGNAL 19
void OpenAPI::OAIEducationUserApi::updateEducationUserSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3);
}

// SIGNAL 20
void OpenAPI::OAIEducationUserApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void OpenAPI::OAIEducationUserApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
