/****************************************************************************
** Meta object code from reading C++ file 'OAIEducationClassApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIEducationClassApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIEducationClassApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIEducationClassApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIEducationClassApi",
        "addUserToClassSignal",
        "",
        "createClassSignal",
        "OAIEducationClass",
        "summary",
        "deleteClassSignal",
        "deleteUserFromClassSignal",
        "getClassSignal",
        "listClassMembersSignal",
        "OAICollection_of_educationUser",
        "listClassesSignal",
        "OAICollection_of_class",
        "updateClassSignal",
        "addUserToClassSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "createClassSignalFull",
        "deleteClassSignalFull",
        "deleteUserFromClassSignalFull",
        "getClassSignalFull",
        "listClassMembersSignalFull",
        "listClassesSignalFull",
        "updateClassSignalFull",
        "addUserToClassSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "createClassSignalE",
        "deleteClassSignalE",
        "deleteUserFromClassSignalE",
        "getClassSignalE",
        "listClassMembersSignalE",
        "listClassesSignalE",
        "updateClassSignalE",
        "addUserToClassSignalEFull",
        "createClassSignalEFull",
        "deleteClassSignalEFull",
        "deleteUserFromClassSignalEFull",
        "getClassSignalEFull",
        "listClassMembersSignalEFull",
        "listClassesSignalEFull",
        "updateClassSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addUserToClassSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createClassSignal'
        QtMocHelpers::SignalData<void(OAIEducationClass)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'deleteClassSignal'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteUserFromClassSignal'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'getClassSignal'
        QtMocHelpers::SignalData<void(OAIEducationClass)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'listClassMembersSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_educationUser)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 5 },
        }}),
        // Signal 'listClassesSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_class)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 5 },
        }}),
        // Signal 'updateClassSignal'
        QtMocHelpers::SignalData<void(OAIEducationClass)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'addUserToClassSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'createClassSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationClass)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'deleteClassSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'deleteUserFromClassSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'getClassSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationClass)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'listClassMembersSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_educationUser)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 10, 5 },
        }}),
        // Signal 'listClassesSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_class)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 12, 5 },
        }}),
        // Signal 'updateClassSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIEducationClass)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'addUserToClassSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'createClassSignalE'
        QtMocHelpers::SignalData<void(OAIEducationClass, QNetworkReply::NetworkError, QString)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'deleteClassSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'deleteUserFromClassSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'getClassSignalE'
        QtMocHelpers::SignalData<void(OAIEducationClass, QNetworkReply::NetworkError, QString)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'listClassMembersSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_educationUser, QNetworkReply::NetworkError, QString)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 5 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'listClassesSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_class, QNetworkReply::NetworkError, QString)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 5 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'updateClassSignalE'
        QtMocHelpers::SignalData<void(OAIEducationClass, QNetworkReply::NetworkError, QString)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'addUserToClassSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'createClassSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'deleteClassSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'deleteUserFromClassSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'getClassSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'listClassMembersSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'listClassesSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'updateClassSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIEducationClassApi, qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIEducationClassApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIEducationClassApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIEducationClassApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addUserToClassSignal(); break;
        case 1: _t->createClassSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[1]))); break;
        case 2: _t->deleteClassSignal(); break;
        case 3: _t->deleteUserFromClassSignal(); break;
        case 4: _t->getClassSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[1]))); break;
        case 5: _t->listClassMembersSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser>>(_a[1]))); break;
        case 6: _t->listClassesSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_class>>(_a[1]))); break;
        case 7: _t->updateClassSignal((*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[1]))); break;
        case 8: _t->addUserToClassSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 9: _t->createClassSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[2]))); break;
        case 10: _t->deleteClassSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 11: _t->deleteUserFromClassSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 12: _t->getClassSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[2]))); break;
        case 13: _t->listClassMembersSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser>>(_a[2]))); break;
        case 14: _t->listClassesSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_class>>(_a[2]))); break;
        case 15: _t->updateClassSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[2]))); break;
        case 16: _t->addUserToClassSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->createClassSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 18: _t->deleteClassSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->deleteUserFromClassSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->getClassSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 21: _t->listClassMembersSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_educationUser>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 22: _t->listClassesSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_class>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 23: _t->updateClassSignalE((*reinterpret_cast<std::add_pointer_t<OAIEducationClass>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 24: _t->addUserToClassSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 25: _t->createClassSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 26: _t->deleteClassSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 27: _t->deleteUserFromClassSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 28: _t->getClassSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 29: _t->listClassMembersSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 30: _t->listClassesSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 31: _t->updateClassSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 32: _t->abortRequestsSignal(); break;
        case 33: _t->allPendingRequestsCompleted(); break;
        case 34: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)()>(_a, &OAIEducationClassApi::addUserToClassSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIEducationClass )>(_a, &OAIEducationClassApi::createClassSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)()>(_a, &OAIEducationClassApi::deleteClassSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)()>(_a, &OAIEducationClassApi::deleteUserFromClassSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIEducationClass )>(_a, &OAIEducationClassApi::getClassSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAICollection_of_educationUser )>(_a, &OAIEducationClassApi::listClassMembersSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAICollection_of_class )>(_a, &OAIEducationClassApi::listClassesSignal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIEducationClass )>(_a, &OAIEducationClassApi::updateClassSignal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationClassApi::addUserToClassSignalFull, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , OAIEducationClass )>(_a, &OAIEducationClassApi::createClassSignalFull, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationClassApi::deleteClassSignalFull, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * )>(_a, &OAIEducationClassApi::deleteUserFromClassSignalFull, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , OAIEducationClass )>(_a, &OAIEducationClassApi::getClassSignalFull, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , OAICollection_of_educationUser )>(_a, &OAIEducationClassApi::listClassMembersSignalFull, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , OAICollection_of_class )>(_a, &OAIEducationClassApi::listClassesSignalFull, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , OAIEducationClass )>(_a, &OAIEducationClassApi::updateClassSignalFull, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::addUserToClassSignalE, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIEducationClass , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::createClassSignalE, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::deleteClassSignalE, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::deleteUserFromClassSignalE, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIEducationClass , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::getClassSignalE, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAICollection_of_educationUser , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::listClassMembersSignalE, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAICollection_of_class , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::listClassesSignalE, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIEducationClass , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::updateClassSignalE, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::addUserToClassSignalEFull, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::createClassSignalEFull, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::deleteClassSignalEFull, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::deleteUserFromClassSignalEFull, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::getClassSignalEFull, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::listClassMembersSignalEFull, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::listClassesSignalEFull, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIEducationClassApi::updateClassSignalEFull, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)()>(_a, &OAIEducationClassApi::abortRequestsSignal, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIEducationClassApi::*)()>(_a, &OAIEducationClassApi::allPendingRequestsCompleted, 33))
            return;
    }
}

const QMetaObject *OpenAPI::OAIEducationClassApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIEducationClassApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI20OAIEducationClassApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIEducationClassApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIEducationClassApi::addUserToClassSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OpenAPI::OAIEducationClassApi::createClassSignal(OAIEducationClass _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OpenAPI::OAIEducationClassApi::deleteClassSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OpenAPI::OAIEducationClassApi::deleteUserFromClassSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OpenAPI::OAIEducationClassApi::getClassSignal(OAIEducationClass _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OpenAPI::OAIEducationClassApi::listClassMembersSignal(OAICollection_of_educationUser _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OpenAPI::OAIEducationClassApi::listClassesSignal(OAICollection_of_class _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OpenAPI::OAIEducationClassApi::updateClassSignal(OAIEducationClass _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OpenAPI::OAIEducationClassApi::addUserToClassSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void OpenAPI::OAIEducationClassApi::createClassSignalFull(OAIHttpRequestWorker * _t1, OAIEducationClass _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void OpenAPI::OAIEducationClassApi::deleteClassSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void OpenAPI::OAIEducationClassApi::deleteUserFromClassSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void OpenAPI::OAIEducationClassApi::getClassSignalFull(OAIHttpRequestWorker * _t1, OAIEducationClass _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void OpenAPI::OAIEducationClassApi::listClassMembersSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_educationUser _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void OpenAPI::OAIEducationClassApi::listClassesSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_class _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void OpenAPI::OAIEducationClassApi::updateClassSignalFull(OAIHttpRequestWorker * _t1, OAIEducationClass _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void OpenAPI::OAIEducationClassApi::addUserToClassSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void OpenAPI::OAIEducationClassApi::createClassSignalE(OAIEducationClass _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void OpenAPI::OAIEducationClassApi::deleteClassSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void OpenAPI::OAIEducationClassApi::deleteUserFromClassSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void OpenAPI::OAIEducationClassApi::getClassSignalE(OAIEducationClass _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2, _t3);
}

// SIGNAL 21
void OpenAPI::OAIEducationClassApi::listClassMembersSignalE(OAICollection_of_educationUser _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2, _t3);
}

// SIGNAL 22
void OpenAPI::OAIEducationClassApi::listClassesSignalE(OAICollection_of_class _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2, _t3);
}

// SIGNAL 23
void OpenAPI::OAIEducationClassApi::updateClassSignalE(OAIEducationClass _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2, _t3);
}

// SIGNAL 24
void OpenAPI::OAIEducationClassApi::addUserToClassSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2, _t3);
}

// SIGNAL 25
void OpenAPI::OAIEducationClassApi::createClassSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3);
}

// SIGNAL 26
void OpenAPI::OAIEducationClassApi::deleteClassSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2, _t3);
}

// SIGNAL 27
void OpenAPI::OAIEducationClassApi::deleteUserFromClassSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2, _t3);
}

// SIGNAL 28
void OpenAPI::OAIEducationClassApi::getClassSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2, _t3);
}

// SIGNAL 29
void OpenAPI::OAIEducationClassApi::listClassMembersSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2, _t3);
}

// SIGNAL 30
void OpenAPI::OAIEducationClassApi::listClassesSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2, _t3);
}

// SIGNAL 31
void OpenAPI::OAIEducationClassApi::updateClassSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1, _t2, _t3);
}

// SIGNAL 32
void OpenAPI::OAIEducationClassApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void OpenAPI::OAIEducationClassApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}
QT_WARNING_POP
