/****************************************************************************
** Meta object code from reading C++ file 'OAIGroupApi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../libre-graph-api-cpp-qt-client-1.0.4/client/OAIGroupApi.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OAIGroupApi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenAPI::OAIGroupApi::qt_create_metaobjectdata<qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenAPI::OAIGroupApi",
        "addMemberSignal",
        "",
        "deleteGroupSignal",
        "deleteMemberSignal",
        "getGroupSignal",
        "OAIGroup",
        "summary",
        "listMembersSignal",
        "OAICollection_of_users",
        "updateGroupSignal",
        "addMemberSignalFull",
        "OAIHttpRequestWorker*",
        "worker",
        "deleteGroupSignalFull",
        "deleteMemberSignalFull",
        "getGroupSignalFull",
        "listMembersSignalFull",
        "updateGroupSignalFull",
        "addMemberSignalE",
        "QNetworkReply::NetworkError",
        "error_type",
        "error_str",
        "deleteGroupSignalE",
        "deleteMemberSignalE",
        "getGroupSignalE",
        "listMembersSignalE",
        "updateGroupSignalE",
        "addMemberSignalEFull",
        "deleteGroupSignalEFull",
        "deleteMemberSignalEFull",
        "getGroupSignalEFull",
        "listMembersSignalEFull",
        "updateGroupSignalEFull",
        "abortRequestsSignal",
        "allPendingRequestsCompleted",
        "tokenAvailable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addMemberSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteGroupSignal'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteMemberSignal'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'getGroupSignal'
        QtMocHelpers::SignalData<void(OAIGroup)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'listMembersSignal'
        QtMocHelpers::SignalData<void(OAICollection_of_users)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Signal 'updateGroupSignal'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addMemberSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'deleteGroupSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'deleteMemberSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'getGroupSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAIGroup)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'listMembersSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, OAICollection_of_users)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 9, 7 },
        }}),
        // Signal 'updateGroupSignalFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'addMemberSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'deleteGroupSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'deleteMemberSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'getGroupSignalE'
        QtMocHelpers::SignalData<void(OAIGroup, QNetworkReply::NetworkError, QString)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'listMembersSignalE'
        QtMocHelpers::SignalData<void(OAICollection_of_users, QNetworkReply::NetworkError, QString)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 7 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'updateGroupSignalE'
        QtMocHelpers::SignalData<void(QNetworkReply::NetworkError, QString)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'addMemberSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'deleteGroupSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'deleteMemberSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'getGroupSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'listMembersSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'updateGroupSignalEFull'
        QtMocHelpers::SignalData<void(OAIHttpRequestWorker *, QNetworkReply::NetworkError, QString)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'abortRequestsSignal'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allPendingRequestsCompleted'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tokenAvailable'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OAIGroupApi, qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenAPI::OAIGroupApi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t>.metaTypes,
    nullptr
} };

void OpenAPI::OAIGroupApi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OAIGroupApi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addMemberSignal(); break;
        case 1: _t->deleteGroupSignal(); break;
        case 2: _t->deleteMemberSignal(); break;
        case 3: _t->getGroupSignal((*reinterpret_cast<std::add_pointer_t<OAIGroup>>(_a[1]))); break;
        case 4: _t->listMembersSignal((*reinterpret_cast<std::add_pointer_t<OAICollection_of_users>>(_a[1]))); break;
        case 5: _t->updateGroupSignal(); break;
        case 6: _t->addMemberSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 7: _t->deleteGroupSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 8: _t->deleteMemberSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 9: _t->getGroupSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAIGroup>>(_a[2]))); break;
        case 10: _t->listMembersSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OAICollection_of_users>>(_a[2]))); break;
        case 11: _t->updateGroupSignalFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1]))); break;
        case 12: _t->addMemberSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->deleteGroupSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->deleteMemberSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->getGroupSignalE((*reinterpret_cast<std::add_pointer_t<OAIGroup>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 16: _t->listMembersSignalE((*reinterpret_cast<std::add_pointer_t<OAICollection_of_users>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->updateGroupSignalE((*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->addMemberSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->deleteGroupSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 20: _t->deleteMemberSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 21: _t->getGroupSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 22: _t->listMembersSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 23: _t->updateGroupSignalEFull((*reinterpret_cast<std::add_pointer_t<OAIHttpRequestWorker*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QNetworkReply::NetworkError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 24: _t->abortRequestsSignal(); break;
        case 25: _t->allPendingRequestsCompleted(); break;
        case 26: _t->tokenAvailable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< OAIHttpRequestWorker* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply::NetworkError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)()>(_a, &OAIGroupApi::addMemberSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)()>(_a, &OAIGroupApi::deleteGroupSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)()>(_a, &OAIGroupApi::deleteMemberSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIGroup )>(_a, &OAIGroupApi::getGroupSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAICollection_of_users )>(_a, &OAIGroupApi::listMembersSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)()>(_a, &OAIGroupApi::updateGroupSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * )>(_a, &OAIGroupApi::addMemberSignalFull, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * )>(_a, &OAIGroupApi::deleteGroupSignalFull, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * )>(_a, &OAIGroupApi::deleteMemberSignalFull, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , OAIGroup )>(_a, &OAIGroupApi::getGroupSignalFull, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , OAICollection_of_users )>(_a, &OAIGroupApi::listMembersSignalFull, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * )>(_a, &OAIGroupApi::updateGroupSignalFull, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::addMemberSignalE, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::deleteGroupSignalE, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::deleteMemberSignalE, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIGroup , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::getGroupSignalE, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAICollection_of_users , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::listMembersSignalE, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::updateGroupSignalE, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::addMemberSignalEFull, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::deleteGroupSignalEFull, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::deleteMemberSignalEFull, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::getGroupSignalEFull, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::listMembersSignalEFull, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)(OAIHttpRequestWorker * , QNetworkReply::NetworkError , QString )>(_a, &OAIGroupApi::updateGroupSignalEFull, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)()>(_a, &OAIGroupApi::abortRequestsSignal, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (OAIGroupApi::*)()>(_a, &OAIGroupApi::allPendingRequestsCompleted, 25))
            return;
    }
}

const QMetaObject *OpenAPI::OAIGroupApi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenAPI::OAIGroupApi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OpenAPI11OAIGroupApiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenAPI::OAIGroupApi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void OpenAPI::OAIGroupApi::addMemberSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OpenAPI::OAIGroupApi::deleteGroupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OpenAPI::OAIGroupApi::deleteMemberSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OpenAPI::OAIGroupApi::getGroupSignal(OAIGroup _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OpenAPI::OAIGroupApi::listMembersSignal(OAICollection_of_users _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OpenAPI::OAIGroupApi::updateGroupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OpenAPI::OAIGroupApi::addMemberSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OpenAPI::OAIGroupApi::deleteGroupSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OpenAPI::OAIGroupApi::deleteMemberSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void OpenAPI::OAIGroupApi::getGroupSignalFull(OAIHttpRequestWorker * _t1, OAIGroup _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void OpenAPI::OAIGroupApi::listMembersSignalFull(OAIHttpRequestWorker * _t1, OAICollection_of_users _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void OpenAPI::OAIGroupApi::updateGroupSignalFull(OAIHttpRequestWorker * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void OpenAPI::OAIGroupApi::addMemberSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void OpenAPI::OAIGroupApi::deleteGroupSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void OpenAPI::OAIGroupApi::deleteMemberSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void OpenAPI::OAIGroupApi::getGroupSignalE(OAIGroup _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void OpenAPI::OAIGroupApi::listMembersSignalE(OAICollection_of_users _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void OpenAPI::OAIGroupApi::updateGroupSignalE(QNetworkReply::NetworkError _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void OpenAPI::OAIGroupApi::addMemberSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3);
}

// SIGNAL 19
void OpenAPI::OAIGroupApi::deleteGroupSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3);
}

// SIGNAL 20
void OpenAPI::OAIGroupApi::deleteMemberSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2, _t3);
}

// SIGNAL 21
void OpenAPI::OAIGroupApi::getGroupSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2, _t3);
}

// SIGNAL 22
void OpenAPI::OAIGroupApi::listMembersSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2, _t3);
}

// SIGNAL 23
void OpenAPI::OAIGroupApi::updateGroupSignalEFull(OAIHttpRequestWorker * _t1, QNetworkReply::NetworkError _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2, _t3);
}

// SIGNAL 24
void OpenAPI::OAIGroupApi::abortRequestsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void OpenAPI::OAIGroupApi::allPendingRequestsCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}
QT_WARNING_POP
