// model-header.mustache

// licenseInfo.mustache

/**
 * Libre Graph API
 * Libre Graph is a free API for cloud collaboration inspired by the MS Graph API.
 *
 * The version of the OpenAPI document: v1.0.4
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

/*
 * OAICollection_of_class.h
 *
 * 
 */

#ifndef OAICollection_of_class_H
#define OAICollection_of_class_H

#include <QJsonObject>

#include "OAIEducationClass.h"
#include <QList>

#include "OAIEnum.h"
#include "OAIObject.h"

namespace OpenAPI {
class OAIEducationClass;


class OAICollection_of_classPrivate;

class OAICollection_of_class : public OAIObject {
public:
    OAICollection_of_class();
    OAICollection_of_class(const OAICollection_of_class &other);
    OAICollection_of_class(QString json);
    ~OAICollection_of_class() override;

    QString asJson() const override;
    QJsonObject asJsonObject() const override;
    void fromJsonObject(QJsonObject json) override;
    void fromJson(QString jsonString) override;

    QList<OAIEducationClass> getValue() const;
    void setValue(const QList<OAIEducationClass> &value);
    bool is_value_Set() const;
    bool is_value_Valid() const;

    virtual bool isSet() const override;
    virtual bool isValid() const override;

private:
    void initializeModel();
    Q_DECLARE_PRIVATE(OAICollection_of_class)
    QSharedPointer<OAICollection_of_classPrivate> d_ptr;
};

} // namespace OpenAPI

Q_DECLARE_METATYPE(OpenAPI::OAICollection_of_class)

#endif // OAICollection_of_class_H
